OC.L10N.register(
    "settings",
    {
    "Unable to change password" : "No fue posible cambiar la contraseña",
    "Very weak password" : "Contraseña muy débil",
    "Weak password" : "Contraseña débil",
    "So-so password" : "Contraseña aceptable",
    "Good password" : "Buena contraseña",
    "Strong password" : "Contraseña fuerte",
    "Groups" : "Grupos",
    "Group list is empty" : "La lista de grupos esta vacía",
    "Unable to retrieve the group list" : "No fue posible recuperar la lista del gurpo",
    "{actor} added you to group {group}" : "{actor} te agregó al grupo {group}",
    "You added {user} to group {group}" : "Agregaste a {user} al grupo {group}",
    "{actor} added {user} to group {group}" : "{actor} agregó a {user} al grupo {group}",
    "An administrator added you to group {group}" : "Un administrador te agregó al grupo {group}",
    "An administrator added {user} to group {group}" : "Un administrador agregó a {user} al grupo {group}",
    "{actor} removed you from group {group}" : "{actor} te eliminó del grupo {group}",
    "You removed {user} from group {group}" : "Eliminaste a {user} del grupo {group}",
    "{actor} removed {user} from group {group}" : "{actor} eliminó a {user} del grupo {group}",
    "An administrator removed you from group {group}" : "Un administrador te eliminó del grupo {group}",
    "An administrator removed {user} from group {group}" : "Un administrador eliminó a {user} del grupo {group}",
    "Your <strong>group memberships</strong> were modified" : "Tus <strong>pertenencias a grupos</strong> fueron modificadas",
    "{actor} changed your password" : "{actor} ha cambiado tu contraseña",
    "You changed your password" : "Cambiaste tu contraseña",
    "Your password was reset by an administrator" : "Tu contraseña ha sido restablecida por un adminsitrador",
    "Your password was reset" : "Se restableció tu contraseña",
    "{actor} changed your email address" : "{actor} ha cambiado tu dirección de correo electrónico",
    "You changed your email address" : "Cambiaste tu dirección de correo electrónico",
    "Your email address was changed by an administrator" : "Tu dirección de correo electrónico ha sido cambiada por un administrador",
    "You created an app password for a session named \"{token}\"" : "Creaste una contraseña de aplicación para una sesión llamada \"{token}\"",
    "An administrator created an app password for a session named \"{token}\"" : "Un administrador creó una contraseña de aplicación para una sesión llamada \"{token}\"",
    "You deleted app password \"{token}\"" : "Eliminaste la contraseña de aplicación \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Cambiaste el nombre de la contraseña de aplicación \"{token}\" a \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Concediste acceso al sistema de archivos a la contraseña de aplicación \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Revocaste el acceso al sistema de archivos de la contraseña de aplicación \"{token}\"",
    "Security" : "Seguridad",
    "You successfully logged in using two-factor authentication (%1$s)" : "Has iniciado sesión exitosamente usando autenticación de dos-factores (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Un intento de autenticación usando autenticación de dos-factores ha fallado (%1$s)",
    "Remote wipe was started on %1$s" : "Se inició el borrado remoto en %1$s",
    "Remote wipe has finished on %1$s" : "El borrado remoto ha finalizado en %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Tu <strong>contraseña</strong> o <strong>correo electrónico</strong> ha sido modificado",
    "Settings" : "Configuraciones ",
    "Could not remove app." : "No se pudo eliminar la aplicación.",
    "Could not update app." : "No se pudo actualizar la aplicación.",
    "Wrong password" : "Contraseña incorrecta",
    "Unable to change personal password" : "No se pudo cambiar la contraseña personal",
    "Saved" : "Guardado",
    "Unable to change password. Password too long." : "No se pudo cambiar la contraseña. La contraseña es demasiado larga.",
    "Authentication error" : "Error de autenticación",
    "Wrong admin recovery password. Please check the password and try again." : "Contraseña de recuperación de administrador incorrecta. Por favor verificala e inténtalo de nuevo.",
    "Administrator documentation" : "Documentación del adminsitrador",
    "User documentation" : "Documentación del usuario",
    "Invalid SMTP password." : "Constraseña SMTP inválida. ",
    "Email setting test" : "Prueba de ajustes de correo",
    "Well done, %s!" : "¡Bien hecho, %s!",
    "If you received this email, the email configuration seems to be correct." : "Si has recibido este correo electrónico, la configuración del correo electrónico parece estar correcta. ",
    "Email could not be sent. Check your mail server log" : "No fue posible enviar el correo electrónico. Por favor verfica la bitácora de tu servidor de correo",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Se presentó un problema al enviar el correo electrónico. Por favor revisa tus configuraciones (Error: %s)",
    "Invalid account" : "Cuenta inválida",
    "Invalid mail address" : "Dirección de correo inválida",
    "Settings saved" : "Se han guardado las configuraciones ",
    "Unable to change full name" : "No fue posible cambiar el nombre completo",
    "Unable to change email address" : "No fue posible cambiar la dirección de correo electrónico",
    "Unable to set invalid phone number" : "No se puede establecer un número de teléfono inválido",
    "Unable to set invalid website" : "No se puede establecer un sitio web inválido",
    "Some account data was invalid" : "Algunos datos de la cuenta son inválidos",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Para poder verificar tu cuenta de Twitter, publica el siguiente tweet en Twitter (por favor asegúrarte de publicar sin ninguna línea en blanco):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Para poder verificar tu sitio Web, agrega el siguiente contendio a tu web-root en '.well-known/CloudIdVerificationCode.txt' (por favor asegurate de que el texto completo este en una sóla línea):",
    "%1$s changed your password on %2$s." : "%1$s cambió tu contraseña el %2$s.",
    "Your password on %s was changed." : "Tu contraseña de %s fue cambiada. ",
    "Your password on %s was reset by an administrator." : "Tu contraseña de %s fue restablecida por un administrador.",
    "Your password on %s was reset." : "Se restableció tu contraseña en %s.",
    "Password for %1$s changed on %2$s" : "La contraseña de %1$s fue cambiada en %2$s",
    "Password changed for %s" : "La contraseña fue cambiada para %s",
    "If you did not request this, please contact an administrator." : "Si no lo solicitaste, por favor contacta a un administrador. ",
    "Your email address on %s was changed." : "Tu dirección de correo electrónico en %s fue cambiada. ",
    "Your email address on %s was changed by an administrator." : "Tu dirección de correo electrónico en %s fue cambiada por un adminsitrador. ",
    "Email address for %1$s changed on %2$s" : "La dirección de correo electrónico de %1$s ha cambiado en %2$s",
    "Email address changed for %s" : "La dirección de correo electrónico fue cambiada para %s",
    "The new email address is %s" : "La nueva dirección de correo electrónico es %s",
    "Your %s account was created" : "Tu cuenta %s ha sido creada",
    "Welcome aboard" : "Bienvenido a bordo",
    "Welcome aboard %s" : "Bienvenido a bordo %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Bienvenido a tu cuenta %s, puedes agregar, proteger y compartir tus datos.",
    "Set your password" : "Establece tu contraseña",
    "Go to %s" : "Ir a %s",
    "Install Client" : "Instalar el cliente",
    "Apps" : "Aplicaciones",
    "Personal" : "Personal",
    "Administration" : "Administración",
    "Users" : "Usuarios",
    "Additional settings" : "Configuraciones adicionales",
    "Administration privileges" : "Privilegios de administración",
    "Groupware" : "Groupware",
    "Overview" : "Generalidades",
    "Basic settings" : "Configuraciones  básicas",
    "Sharing" : "Compartiendo",
    "Availability" : "Disponibilidad",
    "Calendar" : "Calendario",
    "Personal info" : "Información Personal",
    "Mobile & desktop" : "Móvil y escritorio",
    "Email server" : "Servidor de correo electrónico",
    "Background jobs" : "Trabajos en segundo plano",
    "Unlimited" : "Ilimitado",
    "Verifying" : "Verificando",
    "Verifying …" : "Verificando ...",
    "Verify" : "Verificar",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Su directorio de datos y sus archivos probablemente sean accesibles desde Internet. El archivo .htaccess no está funcionando. Se recomienda encarecidamente que configure su servidor web de manera que el directorio de datos ya no sea accesible, o mueva el directorio de datos fuera de la raíz del documento del servidor web.",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "A la base de datos le faltan algunas columnas opcionales. Debido a que agregar columnas en tablas grandes puede llevar tiempo, no se agregaron automáticamente cuando pueden ser opcionales. Al ejecutar \"occ db:add-missing-columns\", se pueden agregar manualmente esas columnas faltantes mientras la instancia sigue funcionando. Una vez que se agregan las columnas, algunas características pueden mejorar la capacidad de respuesta o la usabilidad.",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "A la base de datos le faltan algunas claves principales. Debido a que agregar claves principales en tablas grandes puede llevar tiempo, no se agregaron automáticamente. Al ejecutar \"occ db:add-missing-primary-keys\", se pueden agregar manualmente esas claves principales faltantes mientras la instancia sigue funcionando.",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Esta instancia se está ejecutando en modo de depuración. Solo habilite esto para el desarrollo local y no en entornos de producción.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Este servidor no tiene conexión a Internet: no se pudo acceder a varios puntos finales. Esto significa que algunas funciones, como el montaje de almacenamiento externo, las notificaciones sobre actualizaciones o la instalación de aplicaciones de terceros, no funcionarán. Es posible que tampoco funcione el acceso a archivos de forma remota y el envío de correos electrónicos de notificación. Establezca una conexión desde este servidor a Internet para disfrutar de todas las funciones.",
    "Disabled" : "Deshabilitado",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Se ha habilitado el formato antiguo de cifrado en el servidor. Recomendamos desactivarlo.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La función de PHP \"set_time_limit\" no está disponible. Esto podría generar que la ejecución de scripts se detenga, rompiendo su instalación. Se recomienda ámpliamente habilitar esta función. ",
    "Supported" : "Compatible",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Tu PHP no cuenta con soporte FreeType, lo que resulta en fallas en la imagen de perfil y la interface de configuraciones. ",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP no parece estar configurado correctamente para consultar las variables de ambiente. La prueba con getenv(\"PATH\") sólo regresa una respuesta vacía.",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "El módulo PHP OPcache no está cargado. Para un mejor rendimiento, se recomienda cargarlo en tu instalación de PHP.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "La configuración de solo lectura se ha habilitado. Esto impide establecer algunas configuraciones a través de la interfaz web. Además, el archivo debe hacerse editable manualmente en cada actualización.",
    "Architecture" : "Arquitectura",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Tu base de datos no puede correr con el nivel de aislamiento de transacción de \"READ COMMITTED\".  Puede causar problemas cuando mútiples acciones sean ejecutadas en paralelo.",
    "Profile information" : "Información del perfil",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Foto de perfil, nombre completo, correo electrónico, número de teléfono, dirección, sitio web, Twitter, organización, cargo, titular, biografía y si tu perfil está habilitado",
    "Nextcloud settings" : "Configuración de Nextcloud",
    "Enable" : "Habilitar",
    "Image generation" : "Generación de imágenes",
    "Here you can decide which group can access certain sections of the administration settings." : "Aquí puedes decidir qué grupo puede acceder a determinadas secciones de la configuración de administración.",
    "Unable to modify setting" : "No se pudo modificar la configuración",
    "None" : "Ninguno",
    "Allow apps to use the Share API" : "Permitir que las aplicaciones usen el API para Compartir",
    "Allow resharing" : "Permitir volver a compartir",
    "Allow sharing with groups" : "Permitir compartir con grupos",
    "Restrict users to only share with users in their groups" : "Limitar a los usuarios a sólo compartir con otros usuarios en sus grupos",
    "Allow users to share via link and emails" : "Permitir a los usuarios compartir mediante enlaces y correos electrónicos",
    "Allow public uploads" : "Permitir cargas públicas",
    "Always ask for a password" : "Siempre pedir una contraseña",
    "Enforce password protection" : "Forzar protección de contraseñas",
    "Enforce expiration date" : "Forzar fecha de expiración",
    "Set default expiration date for shares to other servers" : "Establecer fecha de vencimiento predeterminada para los compartidos con otros servidores",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Mostrar texto de descargo de responsabilidad en la página de carga de enlaces públicos (solo se muestra cuando la lista de archivos está oculta)",
    "This text will be shown on the public link upload page when the file list is hidden." : "Este texto se mostrará en la página de carga de la liga pública cuando la lista de archivos esté oculta. ",
    "Default share permissions" : "Permisos predeterminados para compartir",
    "Two-Factor Authentication" : "Autenticación de dos factores",
    "Enforce two-factor authentication" : "Imponer la autenticación de dos factores",
    "Limit to groups" : "Limitar a grupos",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Se puede imponer la autenticación de dos factores solo para ciertos grupos.",
    "Two-factor authentication is enforced for all members of the following groups." : "La autenticación de dos factores se impone a todos los miembros de los siguientes grupos.",
    "Enforced groups" : "Grupos a los que se impone",
    "Two-factor authentication is not enforced for members of the following groups." : "La autenticación de dos factores no se impone a los miembros de los siguientes grupos.",
    "Excluded groups" : "Grupos excluidos",
    "Save changes" : "Guardar cambios",
    "Update to {update}" : "Actualizar a {update}",
    "Remove" : "Eliminar",
    "Featured" : "Destacado",
    "This app is supported via your current Nextcloud subscription." : "Esta aplicación es compatible con tu suscripción actual de Nextcloud.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Las aplicaciones destacadas son desarrolladas por y dentro de la comunidad. Ofrecen funcionalidad central y están listas para su uso en producción.",
    "Disable all" : "Desactivar todo",
    "All apps are up-to-date." : "Todas las aplicaciones están actualizadas.",
    "Icon" : "Ícono",
    "Name" : "Nombre",
    "Version" : "Versión",
    "Level" : "Nivel",
    "Actions" : "Acciones",
    "Results from other categories" : "Resultados de otras categorías",
    "No apps found for your version" : "No se encontraron aplicaciones para tu versión",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n aplicación tiene una actualización disponible","%n aplicaciones tienen una actualización disponible","%n aplicaciones tienen una actualización disponible"],
    "_Update_::_Update all_" : ["Actualizar","Actualizar todo","Actualizar todo"],
    "Group name" : "Nombre del grupo",
    "Loading groups…" : "Cargando grupos...",
    "Loading" : "Cargando",
    "Daemon" : "Demonio",
    "Type" : "Tipo",
    "Display Name" : "Nombre a desplegar",
    "Learn more" : "Conoce más",
    "Confirm" : "Confirmar",
    "Cancel" : "Cancelar",
    "Description" : "Descripción",
    "View in store" : "Ver en la tienda",
    "Visit website" : "Visita el sitio web",
    "Admin documentation" : "Documentación del administrador",
    "Developer documentation" : "Documentación del desarrollador",
    "Details" : "Detalles",
    "All" : "Todos",
    "Limit app usage to groups" : "Limitar el uso de aplicaciones a grupos",
    "No results" : "No hay resultados",
    "Update to {version}" : "Actualizar a {version}",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicación no puede ser instalada porque las siguientes dependencias no están satisfechas:",
    "Author" : "Autor",
    "Categories" : "Categorías",
    "Resources" : "Recursos",
    "Documentation" : "Documentación",
    "Report a bug" : "Reporta un detalle",
    "Request feature" : "Solicitar una funcionalidad",
    "Ask questions or discuss" : "Hacer una pregunta o comentario",
    "Rate" : "Calificar",
    "Changelog" : "Bitácora de cambios",
    "Google Chrome for Android" : "Google Chrome para Android",
    "{productName} iOS app" : "Aplicación de {productName} para iOS",
    "{productName} Android app" : "Aplicación de {productName} para Android",
    "{productName} Talk for iOS" : "{productName} Talk para iOS",
    "{productName} Talk for Android" : "{productName} Talk para Android",
    "This session" : "Esta sesión",
    "Marked for remote wipe" : "Marcado para borrado remoto",
    "Device settings" : "Configuración del dispositivo",
    "Allow filesystem access" : "Permitir acceso al sistema de archivos",
    "Rename" : "Renombrar",
    "Revoke" : "Revocar",
    "Wipe device" : "Borrar dispositivo",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Revocar este token podría evitar el borrado de tu dispositivo si aún no ha comenzado el borrado.",
    "Device" : "Dispositivo",
    "Last activity" : "Última actividad",
    "Devices & sessions" : "Dispositivos y sesiones",
    "Web, desktop and mobile clients currently logged in to your account." : "Clientes web, de escritorio y móviles han iniciado sesión en tu cuenta. ",
    "Error while creating device token" : "Se presentó un error al crear la ficha en el dispositivo",
    "App name" : "Nombre de la aplicación",
    "Create new app password" : "Crear una nueva contraseña de aplicación",
    "Could not copy app password. Please copy it manually." : "No se pudo copiar la contraseña de la aplicación. Cópiala manualmente.",
    "Login" : "Iniciar sesión",
    "Password" : "Contraseña",
    "Show QR code for mobile apps" : "Mostrar código QR para aplicaciones móviles",
    "Unable to update background job mode" : "No se pudo actualizar el modo de tarea en segundo plano",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Para que el servidor funcione correctamente, es importante configurar correctamente las tareas en segundo plano. La opción recomendada es Cron. Consulta la documentación para obtener más información.",
    "Last job execution ran {time}. Something seems wrong." : "La última ejecución de tareas en segundo plano se realizó {time}. Algo parece estar mal.",
    "Last job ran {relativeTime}." : "La última tarea se ejecutó {relativeTime}.",
    "Background job did not run yet!" : "La tarea en segundo plano aún no se ha ejecutado.",
    "AJAX" : "AJAX",
    "Webcron" : "Webcron",
    "Cron (Recommended)" : "Cron (recomendado)",
    "Unable to update profile default setting" : "No se pudo actualizar la configuración predeterminada del perfil",
    "Profile" : "Perfil",
    "Password confirmation is required" : "Se requiere la confirmación de la contraseña",
    "Unable to update server side encryption config" : "No se pudo actualizar la configuración de cifrado en el servidor",
    "Server-side encryption" : "Encripción del lado del servidor",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "La encripción del lado del servidor hace posible encriptar archivos que serán cargados a este servidor. Esto trae consigo algunas limitaciónes como penalizaciones en el desemeño, asi que habilítalo sólo si es necesario. ",
    "Enable server-side encryption" : "Habilitar encripción del lado del servidor",
    "No encryption module loaded, please enable an encryption module in the app menu." : "No se ha cargado un módulo de encripción, por favor habilita un módulo de encripción en el menú de la aplicación. ",
    "Select default encryption module:" : "Selecciona el modulo de encripción predeterminado:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Necesitas migrar tus claves de cifrado del cifrado antiguo (ownCloud <= 8.0) al nuevo. Activa el \"Módulo de cifrado predeterminado\" y ejecuta {command}",
    "Enable encryption" : "Habilitar encripción",
    "Please read carefully before activating server-side encryption:" : "Lee detenidamente antes de activar el cifrado en el servidor:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Una vez que la encripción se encuentre habilitada, todos lo archivos cargados al servidor desde ese momento en tiempo, se encriptarán en el servidor. Sólo será posible deshabilitar la encripción en una fecha posterior si el modulo de encripción activo soporta esa funcionalidad y si todas las preciondiciones están satisfechas (ejem. establecer una llave de recuperación).",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "La encripción por sí sola no garantiza la seguridad del sistema. Por favor consulta la documentación para mayores informes de cómo funciona la aplicación de encripción y de los casos de uso soportados. ",
    "Be aware that encryption always increases the file size." : "Por favor considera que la encripción siempre aumenta el tamaño de los archivos. ",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Siempre es una buena idea generar respaldos de tus datos, en caso de tener encripción asegúrate de respaldar las llaves de encripción junto con tus datos. ",
    "This is the final warning: Do you really want to enable encryption?" : "Esta es la advertencia final: ¿Realmente deseas habilitar la encripción?",
    "Submit" : "Enviar",
    "Rename group" : "Renombrar grupo",
    "Delete group" : "Eliminar grupo",
    "Current password" : "Contraseña actual",
    "New password" : "Nueva contraseña",
    "Choose your profile picture" : "Elige tu foto de perfil",
    "Please select a valid png or jpg file" : "Selecciona un archivo válido PNG o JPG",
    "Error setting profile picture" : "Error al establecer la foto de perfil",
    "Error cropping profile picture" : "Error al recortar la foto de perfil",
    "Error saving profile picture" : "Error al guardar la foto de perfil",
    "Error removing profile picture" : "Error al eliminar la foto de perfil",
    "Your profile picture" : "Tu foto de perfil",
    "Upload profile picture" : "Subir foto de perfil",
    "Choose profile picture from Files" : "Elegir foto de perfil desde Archivos",
    "Remove profile picture" : "Eliminar foto de perfil",
    "The file must be a PNG or JPG" : "El archivo debe ser PNG o JPG",
    "Picture provided by original account" : "Imagen proporcionada por la cuenta original ",
    "Set as profile picture" : "Establecer como foto de perfil",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Ten en cuenta que puede tomar hasta 24 horas para que tu foto de perfil se actualice en todos lados.",
    "You are a member of the following groups:" : "Eres miembro de los siguientes grupos:",
    "Your full name" : "Tu nombre completo",
    "Unable to update primary email address" : "No se pudo actualizar la dirección de correo electrónico principal",
    "Unable to delete additional email address" : "No se pudo eliminar la dirección de correo electrónico adicional",
    "No email address set" : "No se ha establecido la dirección de correo electrónico",
    "Email options" : "Opciones de correo electrónico",
    "Remove primary email" : "Eliminar correo electrónico principal",
    "Delete email" : "Eliminar correo electrónico",
    "This address is not confirmed" : "Esta dirección no está confirmada",
    "Unset as primary email" : "Quitar como correo electrónico principal",
    "Set as primary email" : "Establecer como correo electrónico principal",
    "Additional email address {index}" : "Dirección de correo electrónico adicional {index}",
    "Unable to delete primary email address" : "No se pudo eliminar la dirección de correo electrónico principal",
    "Unable to add additional email address" : "No se pudo agregar la dirección de correo electrónico adicional",
    "Unable to update additional email address" : "No se pudo actualizar la dirección de correo electrónico adicional",
    "Primary email for password reset and notifications" : "Correo electrónico principal para restablecimiento de contraseña y notificaciones",
    "Your handle" : "Nombre de usuario/a",
    "Your headline" : "Título",
    "No language set" : "No se ha configurado ningún idioma",
    "Unable to update language" : "No se pudo actualizar el idioma",
    "Help translate" : "Ayuda a traducir",
    "No locale set" : "No se ha configurado ninguna configuración regional",
    "Unable to update locale" : "No se pudo actualizar la configuración regional",
    "Week starts on {firstDayOfWeek}" : "La semana comienza el {firstDayOfWeek}",
    "Your city" : "Tu ciudad",
    "Your organisation" : "Tu organización",
    "Your phone number" : "Su número telefónico",
    "Edit your Profile visibility" : "Editar la visibilidad de tu perfil",
    "Unable to update profile enabled state" : "No se pudo actualizar el estado habilitado del perfil",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Se respeta la configuración más restrictiva de visibilidad o alcance en tu perfil. Por ejemplo, si la visibilidad está configurada en \"Mostrar a todos\" y el alcance está configurado en \"Privado\", se respeta \"Privado\".",
    "Unable to update visibility of {displayId}" : "No se pudo actualizar la visibilidad de {displayId}",
    "Your role" : "Tu cargo",
    "Timezone" : "Zona horaria",
    "Your website" : "Tu sitio web",
    "Unable to update {property}" : "No se pudo actualizar {property}",
    "No {property} set" : "Ningún {property} establecido",
    "Change scope level of {property}, current scope is {scope}" : "Cambiar el nivel de alcance de {property}, el alcance actual es {scope}",
    "Unable to update federation scope of the primary {property}" : "No se pudo actualizar el alcance de federación del {property} principal",
    "Unable to update federation scope of additional {property}" : "No se pudo actualizar el alcance de federación del {property} adicional",
    "Add additional email" : "Agregar correo electrónico adicional",
    "Add" : "Guardar",
    "Create" : "Crear",
    "Change" : "Cambiar",
    "Delete" : "Borrar",
    "Reshare" : "Recompartir",
    "School" : "Escuela",
    "Default language" : "Idioma predeterminado",
    "Common languages" : "Idiomas comunes",
    "Other languages" : "Otros idiomas",
    "Password change is disabled because the master key is disabled" : "El cambio de contraseña está deshabilitado porque la clave maestra está deshabilitada",
    "Manager" : "Administrador",
    "Display name" : "Nombre para mostrar",
    "Either password or email is required" : "Se requiere una contraseña o un correo electrónico",
    "Password (required)" : "Contraseña (requerida)",
    "Email (required)" : "Correo electrónico (requerido)",
    "Email" : "Correo electrónico",
    "Quota" : "Cuota",
    "Language" : "Idioma",
    "Set default language" : "Establecer idioma predeterminado",
    "Total rows summary" : "Resumen total de filas.",
    "Scroll to load more rows" : "Desplázate para cargar más filas",
    "Password or insufficient permissions message" : "Contraseña o mensaje de permisos insuficientes",
    "Avatar" : "Avatar",
    "Account name" : "Nombre de la cuenta",
    "Group admin for" : "Administrador del grupo para",
    "Storage location" : "Úbicación del almacenamiento",
    "Last login" : "Último inicio de sesión",
    "Account actions" : "Acciones de la cuenta",
    "{size} used" : "{size} usado",
    "Delete account" : "Borrar cuenta",
    "Resend welcome email" : "Reenviar correo de bienvenida",
    "Remote wipe of devices" : "Borrado remoto de dispositivos",
    "Wipe {userid}'s devices" : "Borrar dispositivos de {userid}",
    "Wiped {userid}'s devices" : "Se borraron los dispositivos de {userid}",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Eliminar por completo la cuenta de {userid}, incluidos todos los archivos personales, datos de aplicaciones, etc.",
    "Account deletion" : "Borrado de cuenta",
    "Delete {userid}'s account" : "Borrar la cuenta de {userid}",
    "Display name was successfully changed" : "Se cambió correctamente el nombre para mostrar",
    "Password was successfully changed" : "Se cambió correctamente la contraseña",
    "Email was successfully changed" : "Se cambió correctamente el correo electrónico",
    "Welcome mail sent!" : "¡Correo de bienvenida enviado!",
    "Set the language" : "Establecer el idioma",
    "Done" : "Hecho",
    "Edit" : "Editar",
    "Visibility" : "Visibilidad",
    "Show storage path" : "Mostrar ruta de almacenamiento",
    "Show last login" : "Mostrar último inicio de sesión",
    "Sorting" : "Ordenar",
    "Send email" : "Enviar correo electrónico",
    "Defaults" : "Valores predeterminados",
    "Default quota" : "Cuota predeterminada",
    "Select default quota" : "Seleccionar cuota predeterminada",
    "Server error while trying to complete WebAuthn device registration" : "Error del servidor al intentar completar el registro del dispositivo WebAuthn",
    "Passwordless authentication requires a secure connection." : "La autenticación sin contraseña requiere una conexión segura.",
    "Add WebAuthn device" : "Agregar dispositivo WebAuthn",
    "Please authorize your WebAuthn device." : "Autoriza tu dispositivo WebAuthn.",
    "Unnamed device" : "Dispositivo sin nombre",
    "Passwordless Authentication" : "Autenticación sin contraseña",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Configura tu cuenta para la autenticación sin contraseña siguiendo el estándar FIDO2.",
    "No devices configured." : "No hay dispositivos configurados.",
    "The following devices are configured for your account:" : "Los siguientes dispositivos están configurados para tu cuenta:",
    "Your browser does not support WebAuthn." : "Tu navegador no admite WebAuthn.",
    "Security & setup warnings" : "Advertencias de seguridad y configuración",
    "Try again" : "Reintentar",
    "All checks passed." : "Pasaron todas las verificaciones. ",
    "There are some errors regarding your setup." : "Hay algunos errores en tu configuración.",
    "There are some warnings regarding your setup." : "Hay algunas advertencias en tu configuración.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Como administrador, puedes hacer ajustes finos al comportamiento de compartir. Por favor consulta la documentación para más información. ",
    "You need to enable the File sharing App." : "Debes habilitar la aplicación Compartir archivos.",
    "Apply" : "Aplicar",
    "Admins" : "Administradores",
    "Sending…" : "Enviando...",
    "Email sent" : "Correo electrónico enviado",
    "Location" : "Ubicación",
    "Profile picture" : "Foto de perfil",
    "About" : "Acerca de",
    "Full name" : "Nombre completo",
    "Additional email" : "Correo electrónico adicional",
    "Fediverse (e.g. Mastodon)" : "Fediverse (por ejemplo, Mastodon)",
    "Headline" : "Título",
    "Organisation" : "Organización",
    "Phone number" : "Número de teléfono",
    "Role" : "Rol",
    "Website" : "Sitio web",
    "Profile visibility" : "Visibilidad del perfil",
    "Locale" : "Configuración regional",
    "Private" : "Privado",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Solo visible para las personas que coinciden a través de la integración del número de teléfono mediante Talk en dispositivos móviles",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "No disponible, ya que esta propiedad es necesaria para la funcionalidad básica, incluyendo el intercambio de archivos y las invitaciones de calendario.",
    "Local" : "Local",
    "Only visible to people on this instance and guests" : "Solo visible para las personas en esta instancia y los invitados",
    "Federated" : "Federado",
    "Only synchronize to trusted servers" : "Solo sincronizar con servidores de confianza",
    "Published" : "Publicado",
    "Synchronize to trusted servers and the global and public address book" : "Sincronizar con servidores de confianza y la libreta de direcciones global y pública",
    "Your apps" : "Tus aplicaciones",
    "Active apps" : "Aplicaciones activas",
    "Disabled apps" : "Aplicaciones deshabilitadas",
    "Updates" : "Actualizaciones",
    "App bundles" : "Paquetes de aplicación",
    "Featured apps" : "Aplicaciones destacadas",
    "Show to everyone" : "Mostrar a todos",
    "Hide" : "Ocultar",
    "Download and enable" : "Descargar y habilitar",
    "Disable" : "Deshabilitar",
    "The app will be downloaded from the App Store" : "La aplicación se descargará desde la App Store",
    "Unknown" : "Desconocido",
    "Never" : "Nunca",
    "An error occurred during the request. Unable to proceed." : "Ocurrió un error durante la solicitud. No se puede continuar.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Error: Esta aplicación no se puede habilitar porque hace que el servidor sea inestable",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "La aplicación ha sido habilitada pero necesita ser actualizada. Serás redireccionado a la página de actualización en 5 segundos. ",
    "Do you really want to wipe your data from this device?" : "¿Realmente deseas borrar tus datos de este dispositivo?",
    "Confirm wipe" : "Confirmar borrado",
    "Error while wiping the device with the token" : "Error al borrar el dispositivo con el token",
    "Error while updating device token name" : "Error al actualizar el nombre del token del dispositivo",
    "Error while updating device token scope" : "Error al actualizar el alcance del token del dispositivo",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Había demasiadas solicitudes desde tu red. Vuelve a intentarlo más tarde o contacta a tu administrador si se trata de un error.",
    "Error" : "Error",
    "Forum" : "Foro",
    "Legal notice" : "Aviso legal",
    "Privacy policy" : "Política de privacidad",
    "None/STARTTLS" : "Ninguno/STARTTLS",
    "SSL" : "SSL",
    "Open documentation" : "Abrir documentación",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Es importante preparar este servidor para poder enviar correos electrónicos, como para restablecer contraseñas y notificaciones. ",
    "Send mode" : "Modo de envío",
    "Encryption" : "Encripción",
    "Sendmail mode" : "Modo Sendmail",
    "From address" : "De la dirección",
    "Server address" : "Dirección del servidor",
    "Port" : "Puerto",
    "Authentication" : "Autenticación",
    "Authentication required" : "Autenticación requerida",
    "Credentials" : "Credenciales",
    "SMTP Password" : "Contraseña SMTP",
    "Save" : "Guardar",
    "Test and verify email settings" : "Probar y verificar la configuración del correo electrónico",
    "Reasons to use Nextcloud in your organization" : "Razones para usar Nextcloud en tu organización",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desarrollado por la  {communityopen}comunidad Nextcloud {linkclose}, el {githubopen}código fuente {linkclose} está licenciado bajo  {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Da un Like a nuestra página de Facebook",
    "Follow us on Mastodon" : "Síguenos en Mastodon",
    "Check out our blog" : "Visita nuestro blog",
    "Subscribe to our newsletter" : "Suscribete a nuestro boletín",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Esta versión comunitaria de Nextcloud no cuenta con soporte y las notificaciones instantáneas no están disponibles.",
    "Use a second factor besides your password to increase security for your account." : "Utiliza un segundo factor además de tu contraseña para aumentar la seguridad de tu cuenta.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Si utilizas aplicaciones de terceros para conectarte a Nextcloud, asegúrate de crear y configurar una contraseña de aplicación para cada una antes de habilitar la autenticación de segundo factor.",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión mínima de Nextcloud asignada. Esto será un error en el futuro.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión máxima de Nextcloud asignada. Esto será un error en el futuro.",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "En caso de pérdida del dispositivo o salida de la organización, esto puede borrar de forma remota los datos de Nextcloud de todos los dispositivos asociados con {userid}. Solo funciona si los dispositivos están conectados a Internet.",
    "Adding your device …" : "Agregando tu dispositivo ...",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Esta aplicación no está marcada como compatible con tu versión de Nextcloud. Si continúas, aún podrás instalar la aplicación. Ten en cuenta que es posible que la aplicación no funcione como se espera.",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Es importante para la seguridad y el rendimiento de tu instancia que todo esté configurado correctamente. Para ayudarte con eso, realizamos algunas comprobaciones automáticas. Consulta la documentación enlazada para obtener más información.",
    "Checking for system and security issues." : "Comprobando problemas del sistema y de seguridad.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Por favor, revisa las <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">guías de instalación ↗</a> y verifica si hay errores o advertencias en el <a href=\"%2$s\">registro</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Verifica la seguridad de tu Nextcloud con nuestro <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">escáner de seguridad ↗</a>."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
